=======
Credits
=======

Development Lead
----------------

* Jonas Teufel <jonseb1998@gmail.com>

Contributors
------------

* Michele Caselle <michele.caselle@kit.edu>: Bash scripts, which control the camera behaviour
